/***************************************************************************
 *   Copyright (C) 2005 by Yuri Vatis   																								*
 *   vatis@tnt.uni-hannover.de																														*
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <QMainWindow>
#include <QDir>
#include "controlbar.h"
#include "display.h"

class HelpWidget;
class QFileDialog;
class QTimer;
class QPushButton;

class MainWindow : public QMainWindow{
Q_OBJECT
	public:
		MainWindow(QWidget * parent = 0, Qt::WFlags flags = 0);
		~MainWindow();
		void controlToolBoxClosed();
		void sequenceClosed();
		void checkOpen1();
		void diffClosed();
		void showYBlocks(QMouseEvent *event);
		void init(int sizeX, int sizeY, bool loop, bool play, int diff, int format, int frequency, QString f1Name, QString f2Name);
		bool isPlaying();
	protected:
		virtual void closeEvent(QCloseEvent * e );
		virtual void moveEvent(QMoveEvent*);
		virtual void resizeEvent(QResizeEvent*);
		virtual void focusInEvent ( QFocusEvent * event );
	public slots:
		void open1();
		void open2();
		void loadFiles();
		void closeApplication();
		void copyToClipboard();
		void toggleControlToolBoxView();
		void showNextFrame();
		void showPreviousFrame();
		void showFrame(int fr_nr);
		void playVideo();
		void playNextFrame();
		void setControlToolBoxClosed();
		void stopVideo();
		void pauseVideo();
		void setLoop();
		void setFrequency();
		void showLinDifference();
		void showLogDifference();
		void showAbout();
	private:
		void showDifference(bool);
		void createMenus();
		void createActions();
		void createSignalSlotConnections();
		void initFileDialog();
		void 	moveControlToolBoxToMainWindow();
		ControlToolBox *controlToolBox;
		QMenuBar *menuBar;
		QMenu    *fileMenu;
		QMenu		 *editMenu;
		QMenu    *viewMenu;
		QMenu    *helpMenu;
		QAction  *open1Act;
		QAction  *open2Act;
		QAction  *exitAct;
		QAction	 *clip1Act;
		QAction	 *clip2Act;
		QAction	 *clipDAct;
		QAction  *viewControlToolBoxAct;
		QMenu    *viewDiffMenu;
		QAction  *viewLinDiffAct;
		QAction  *viewLogDiffAct;
		QAction  *aboutYUVAct;

		int fr1nr;
		int fr2nr;

		QFileDialog *fileDialog;
		QDir currentDir;
		QString file1Name;
		QString file2Name;
		bool file1open;
		bool file2open;
		bool diffopen;
		bool diffType;		// 0- linear, 1 - logarithmic
		
		QTimer *timer;

		Seqdis	*seqdisplay1;
		Seqdis	*seqdisplay2;
		Difference  *difference;
		
		bool loop;
		bool play;
		int frequency;

		HelpWidget *helpWidget;
};

class HelpWidget : public QWidget{
	Q_OBJECT
	public:
		HelpWidget(QWidget * parent = 0, Qt::WFlags flags = 0);
		QTabWidget *tabWidget;
		QWidget		 *aboutWidget;
		QWidget    *authorWidget;
		QWidget		 *thankstoWidget;
		QWidget		 *licenceWidget;
	public slots:
		void			closeButtonClicked();
	protected:
		virtual void resizeEvent(QResizeEvent *);
	private:
		int					borderX;
		int					borderY;
		QPushButton *closeButton;
		int 				buttonsizeX;
		int					buttonsizeY;
		QLabel			*picLabel;
		QLabel			*nameLabel;
		QLabel			*aboutLabel;
		QLabel			*authorLabel;
		QLabel			*thankstoLabel;
		QLabel			*licenceLabel;
};

#endif
